==> kazehakase-0.2.1.tar.gz: kazehakase-0.2.1/src/actions/kz-bookmark-action.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2003 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-bookmark-action.h,v 1.3 2004/09/30 00:06:06 ikezoe Exp $
 */

#ifndef __KZ_BOOKMARK_ACTION_H__
#define __KZ_BOOKMARK_ACTION_H__

#include <gtk/gtk.h>
#include "kz-bookmark.h"

G_BEGIN_DECLS

#define KZ_TYPE_BOOKMARK_ACTION			(kz_bookmark_action_get_type ())
#define KZ_BOOKMARK_ACTION(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_BOOKMARK_ACTION, KzBookmarkAction))
#define KZ_BOOKMARK_ACTION_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_BOOKMARK_ACTION, KzBookmarkActionClass))
#define KZ_IS_BOOKMARK_ACTION(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_BOOKMARK_ACTION))
#define KZ_IS_BOOKMARK_ACTION_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_BOOKMARK_ACTION))
#define KZ_BOOKMARK_ACTION_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_BOOKMARK_ACTION, KzBookmarkActionClass))

typedef struct _KzBookmarkAction	KzBookmarkAction;
typedef struct _KzBookmarkActionClass	KzBookmarkActionClass;
typedef struct _KzBookmarkActionPriv	KzBookmarkActionPriv;

struct _KzBookmarkAction
{
	GtkAction   parent;

	KzBookmarkActionPriv *priv;
};

struct _KzBookmarkActionClass
{
	GtkActionClass parent_class;
};

GtkType    kz_bookmark_action_get_type     (void);

G_END_DECLS

#endif /* __KZ_BOOKMARK_ACTION_H__ */

==> kazehakase_0.4.3.orig.tar.gz: kazehakase-0.4.3.orig/src/actions/kz-bookmark-action.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2003 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-bookmark-action.h,v 1.4 2004/11/25 07:28:47 ikezoe Exp $
 */

#ifndef __KZ_BOOKMARK_ACTION_H__
#define __KZ_BOOKMARK_ACTION_H__

#include <gtk/gtk.h>
#include "kz-bookmark.h"

G_BEGIN_DECLS

#define KZ_TYPE_BOOKMARK_ACTION			(kz_bookmark_action_get_type ())
#define KZ_BOOKMARK_ACTION(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_BOOKMARK_ACTION, KzBookmarkAction))
#define KZ_BOOKMARK_ACTION_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_BOOKMARK_ACTION, KzBookmarkActionClass))
#define KZ_IS_BOOKMARK_ACTION(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_BOOKMARK_ACTION))
#define KZ_IS_BOOKMARK_ACTION_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_BOOKMARK_ACTION))
#define KZ_BOOKMARK_ACTION_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_BOOKMARK_ACTION, KzBookmarkActionClass))

typedef struct _KzBookmarkAction	KzBookmarkAction;
typedef struct _KzBookmarkActionClass	KzBookmarkActionClass;
typedef struct _KzBookmarkActionPriv	KzBookmarkActionPriv;

struct _KzBookmarkAction
{
	GtkAction   parent;

	KzBookmarkActionPriv *priv;
};

struct _KzBookmarkActionClass
{
	GtkActionClass parent_class;
};

GType    kz_bookmark_action_get_type     (void) G_GNUC_CONST;

G_END_DECLS

#endif /* __KZ_BOOKMARK_ACTION_H__ */
